@@ -1,5 +1,7 @@
 #     纯净ORM
-from CACodeFramework.MainWork.CACodeRepository import ParseUtil
+from CACodeFramework.MainWork.opera import obj_dict, op_db
+from CACodeFramework.util.ParseUtil import ParseUtil
+
 from CACodeFramework.field.sql_fields import *
 
 
@@ -19,12 +21,14 @@ class CACodePureORM(object):
         初始化ORM
         :param repository:仓库
         """
+        self.parses = op_db.parses()
         self.args = []
         self.params = []
         if repository is None:
             raise SyntaxError('')
         self.repository = repository
         self.__table_name__ = '{}{}{}'.format(subscript, repository.__table_name__, subscript)
+        self.parses = obj_dict.parses()
 
     # ------------------------主键--------------------------
 
@@ -37,29 +41,39 @@ class CACodePureORM(object):
         :param pojo:需要插入的对象
         """
         # 添加insert关键字
-        self.args.append(insert_str)
-        self.args.append('{}{}'.format(self.__table_name__, left_par))
-        _dict = pojo.__dict__
-        keys = []
-        for key, value in _dict.items():
-            if value is None:
-                continue
-            keys.append('`{}`{}'.format(key, comma))
-            self.params.append(value)
-        for i in keys:
-            self.args.append(i)
-        # 将最后一个字段的逗号改成空格
-        self.rep_sym(comma, space)
-        self.args.append(right_par)
-        self.args.append('{}{}'.format(values_str, left_par))
-        for i in keys:
-            self.args.append('%s{}'.format(comma))
-        # 将最后一个字段的逗号改成空格
-        self.rep_sym(comma, space)
-        self.args.append(right_par)
+        # self.args.append(insert_str)
+        # self.args.append('{}{}'.format(self.__table_name__, left_par))
+        sql = obj_dict.parses().parse_insert(pojo, self.__table_name__.replace('`', ''))
+        self.args.append(sql['sql'])
+        self.params = sql['params']
+
+        # _dict = pojo.__dict__
+        # keys = []
+        # # 解析item
+        # for key, value in _dict.items():
+        #     # 去除为空的键
+        #     if value is None:
+        #         continue
+        #     keys.append('`{}`{}'.format(key, comma))
+        #     self.params.append(value)
+        # for i in keys:
+        #     self.args.append(i)
+        # # 将最后一个字段的逗号改成空格
+        # self.rep_sym(comma, space)
+        # # 加上右边括号
+        # self.args.append(right_par)
+        # self.args.append('{}{}'.format(values_str, left_par))
+        # for i in keys:
+        #     self.args.append('%s{}'.format(comma))
+        # # 将最后一个字段的逗号改成空格
+        # self.rep_sym(comma, space)
+        # self.args.append(right_par)
         return self
 
     def delete(self):
+        """
+        删除
+        """
         self.args.append(delete_str)
         self.args.append(from_str)
         self.args.append(self.__table_name__)
@@ -75,36 +89,68 @@ class CACodePureORM(object):
         self.args.append(update_sql)
         return self
 
-    def find(self, *args):
+    def find(self, *args, **kwargs):
         """
         查
         example:
             find('all')
-            find('param1','param2','param3')
+            find('param1',asses=['p'],h_func=True)
+        Attributes:
+            asses:将对应的字段转成另一个别名,不需要转换的使用None标识
+            h_func:不将字段转换成 `%s` 格式
+        更新:
+            如果args字段长度为0,默认为查找全部
         """
         self.args.append(find_str)
         fields = ''
-        if 'all'.upper() == args[0].upper():
+        # 如果有as字段
+        asses = None
+        if 'asses' in kwargs.keys():
+            asses = kwargs['asses']
+        # 如果包含方法的字段，则不加密
+        func_flag = False
+        if 'h_func' in kwargs.keys():
+            func_flag = kwargs['h_func']
+        # 1.1.0.05更新,默认为all
+        _all = False
+        if len(args) == 0:
+            _all = True
+        # 如果存在all
+        # 1.1.1.2修复：tuple index out of range
+        if _all or 'all'.upper() == args[0].upper():
             # 如果包含all关键字,则使用解析工具解析成字段参数
-            fields = ParseUtil(*self.repository.fields, is_field=True).parse_key()
-
+            if not func_flag:
+                fields = ParseUtil(*self.repository.fields, is_field=True).parse_key()
+            else:
+                fields = ParseUtil(*self.repository.fields, is_field=True).parse_key(is_field=False)
         else:
-            fields = ParseUtil(*args, is_field=True).parse_key()
-        self.args.append(fields)
+            if not func_flag:
+                fields = ParseUtil(*args, is_field=True).parse_key()
+            else:
+                fields = ParseUtil(*args, is_field=True).parse_key(is_field=False)
+        # 解决as问题
+        if asses is not None:
+            fs = fields.split(',')
+            if len(fs) != len(asses):
+                # 匿名参数长度与字段长度不符合
+                raise TypeError('The length of the anonymous parameter does not match the length of the field')
+            fs_cp = []
+            for i, v in enumerate(fs):
+                if asses[i] is not None:
+                    self.args.append('{}{}{}'.format(v, asses_str, asses[i]))
+                else:
+                    self.args.append(v)
+                # 逗号
+                self.args.append(comma)
+        else:
+            self.args.append(fields)
+        if asses is not None:
+            # 去掉末尾的逗号
+            self.rep_sym()
         #     加上from关键字
         self.con_from()
         return self
 
-    # ------------------------中层参数--------------------------
-    def by(self, *args):
-        """
-        根据
-        example:
-            find('all').by('')
-        """
-        self.args.append(by_str)
-        return self
-
     def order_by(self, *args):
         """
         根据什么查
@@ -113,8 +159,22 @@ class CACodePureORM(object):
             find('all').order_by('param').end()
             find('all').order_by('p1','p2').desc().limit(10,20)
         """
-        self.args.append(order_by_str)
-        for i in args:
+        return self.by_opera(field=order_by_str, args_list=args)
+
+    def group_by(self, *args):
+        """
+        聚合函数
+        example:
+            select shop_id,count(*) as count from comments group by shop_id having count>1;
+        """
+        return self.by_opera(field=group_by_str, args_list=args)
+
+    def by_opera(self, field, args_list):
+        """
+        根据什么查
+        """
+        self.args.append(field)
+        for i in args_list:
             self.args.append(subscript)
             self.args.append(i)
             self.args.append(subscript)
@@ -126,15 +186,15 @@ class CACodePureORM(object):
         """
         当....
         example:
-            find('ALL').where(param='%s',value=['value']) - 默认符号为等于 ==
-            find('ALL').where(param='==%s',value=['value'])
-            find('ALL').where(param='>%d',value=['1'])
-            find('ALL').where(param='<%d',value=['1'])
-            find('ALL').where(param='<=%d',value=['1'])
-            find('ALL').where(param='>=%.2f',value=['1.1'])
-            find('ALL').where(param='!=%.2f',value=['1.1'])
+            find('ALL').where(param='%s') - 默认符号为等于 ==
+            find('ALL').where(param='==%s')
+            find('ALL').where(param='>%d')
+            find('ALL').where(param='<%d')
+            find('ALL').where(param='<=%d')
+            find('ALL').where(param='>=%.2f')
+            find('ALL').where(param='!=%.2f')
         复杂语法:
-            find('ALL').where(param='+%d/%d==%d',value=[1,10,12])
+            find('ALL').where(param='+%d/%d==%d')
             find('ALL').where(param='-%.2f*%d==12')
             find('ALL').where(param='*10-1==12')
             find('ALL').where(param='/10+1==12')
@@ -206,13 +266,13 @@ class CACodePureORM(object):
 
     # ------------------------预设符--------------------------
 
-    def ander(self, **kwargs):
+    def ander(self):
         """
         和
         example:
-        update('table').set('param1','value1').and().set('param2','value2')
-        update('table').set('param1','value1').and().set('param2','value2').end()
-        update('table').set('param1','value1').and().set('param2','value2').where('param3=value3').end()
+            update('table').set('param1','value1').and().set('param2','value2')
+            update('table').set('param1','value1').and().set('param2','value2').end()
+            update('table').set('param1','value1').and().set('param2','value2').where('param3=value3').end()
         """
         self.args.append(ander_str)
         return self
@@ -236,7 +296,7 @@ class CACodePureORM(object):
             )
             _result_objs = []
             for i in _result:
-                _obj = self.repository.parse_obj(data=i)
+                _obj = self.parses.parse_obj(data=i, participants=self.repository.participants)
                 _result_objs.append(_obj)
             _result = _result_objs
         else:
@@ -260,11 +320,19 @@ class CACodePureORM(object):
             # 然后加上表名
             self.args.append(self.__table_name__)
 
-    def rep_sym(self, sym, rep):
+    def append(self, app_sql):
+        """
+        末尾追加一些sql
+        """
+        self.args.append(app_sql)
+        return self
+
+    def rep_sym(self, sym=',', rep=''):
         """
         将最后一个参数包含的指定字符替换为指定字符
         """
         self.args[len(self.args) - 1] = str(self.args[len(self.args) - 1]).replace(sym, rep)
+        return self
 
     def end(self):
         return self.run()
