@@ -17,6 +17,8 @@ where_str = space + 'WHERE' + space
 by_str = space + 'BY' + space
 # 根据排序
 order_by_str = space + 'ORDER BY' + space
+# 根据
+group_by_str = space + 'GROUP BY' + space
 # 倒叙
 desc_str = space + 'DESC' + space
 # 设置
@@ -31,6 +33,8 @@ from_str = space + 'FROM' + space
 value_str = space + 'VALUE' + space
 # 多个值
 values_str = space + 'VALUES' + space
+# as
+asses_str = space + 'as' + space
 # 运算符
 symbol = '>> << == <= >= != - + / * %'.split(' ')
 left_par = space + '(' + space
