@@ -1,10 +1,17 @@
+import sys
+
+from CACodeFramework.util.Log import CACodeLog
 from dbutils.pooled_db import PooledDB
 import pymysql
 
+from CACodeFramework.MainWork.exception import e_except
+from CACodeFramework.field import e_fields
+
 
 def parse_kwa(db, **kwargs):
     """
     解析并执行sql
+
     :param db:db_util对象
     :param kwargs:包含所有参数:
             last_id:是否需要返回最后一行数据,默认False
@@ -19,7 +26,9 @@ def parse_kwa(db, **kwargs):
         else:
             sql = kwargs['sql']
         if 'print_sql' in kwargs.keys() and kwargs['print_sql'] is True:
-            print(sql)
+            _l = sys._getframe().f_back.f_lineno
+            e_except.warn(obj=db, line=_l, task_name='Print Sql', f_warn=e_fields.INFO, msg=sql)
+            CACodeLog.log(_obj=db, msg='Being Initialize this object')
         cursor.execute(sql)
         return cursor
     except Exception as e:
